@@ -404,23 +404,40 @@ static VN_pair vn_lstyle[ ] =
     VN( FL_NORMAL_STYLE ),
     VN( FL_BOLD_STYLE ),
     VN( FL_ITALIC_STYLE ),
+    VN( FL_BOLD_ITALIC_STYLE ),
     VN( FL_BOLDITALIC_STYLE ),
+
     VN( FL_FIXED_STYLE ),
+    VN( FL_FIXED_BOLD_STYLE ),
     VN( FL_FIXEDBOLD_STYLE ),
+    VN( FL_FIXED_ITALIC_STYLE ),
     VN( FL_FIXEDITALIC_STYLE ),
+    VN( FL_FIXED_BOLD_ITALIC_STYLE ),
     VN( FL_FIXEDBOLDITALIC_STYLE ),
+
     VN( FL_SERIF_STYLE ),
-    VN( FL_SERIFBOLD_STYLE ),
+    VN( FL_SERIF_BOLD_STYLE ),
+    VN( FL_SERIF_BOLD_STYLE ),
+    VN( FL_SERIF_ITALIC_STYLE ),
     VN( FL_SERIFITALIC_STYLE ),
+    VN( FL_SERIF_BOLD_ITALIC_STYLE ),
     VN( FL_SERIFBOLDITALIC_STYLE ),
     VN( FL_MISC_STYLE ),
+    VN( FL_MISC_BOLD_STYLE ),
     VN( FL_MISCBOLD_STYLE ),
+    VN( FL_MISC_ITALIC_STYLE ),
     VN( FL_MISCITALIC_STYLE ),
+    VN( FL_MISC_BOLD_ITALIC_STYLE ),
     VN( FL_MISCBOLDITALIC_STYLE ),
+
     VN( FL_TIMES_STYLE ),
+    VN( FL_TIMES_BOLD_STYLE ),
     VN( FL_TIMESBOLD_STYLE ),
+    VN( FL_TIMES_ITALIC_STYLE ),
     VN( FL_TIMESITALIC_STYLE ),
+    VN( FL_TIMES_BOLD_ITALIC_STYLE ),
     VN( FL_TIMESBOLDITALIC_STYLE ),
+
     VN( FL_SHADOW_STYLE ),
     VN( FL_ENGRAVED_STYLE ),
     VN( FL_EMBOSSED_STYLE ),
