@@ -38,9 +38,9 @@
 static int
 handle_box( FL_OBJECT * obj,
             int         event,
-            FL_Coord    mx   FL_UNUSED_ARG,
-            FL_Coord    my   FL_UNUSED_ARG,
-            FL_Char     key  FL_UNUSED_ARG,
+            FL_COORD    mx   FL_UNUSED_ARG,
+            FL_COORD    my   FL_UNUSED_ARG,
+            FL_VAL      key  FL_UNUSED_ARG,
             void      * ev   FL_UNUSED_ARG )
 {
     switch ( event )
@@ -48,7 +48,7 @@ handle_box( FL_OBJECT * obj,
         case FL_DRAW:
             fl_draw_box( obj->boxtype, obj->x, obj->y, obj->w, obj->h,
                          obj->col1, obj->bw );
-            /* fall through */
+            break;
 
         case FL_DRAWLABEL:
             if ( obj->label && *obj->label )
@@ -73,10 +73,10 @@ handle_box( FL_OBJECT * obj,
 
 FL_OBJECT *
 fl_create_box( int          type,
-               FL_Coord     x,
-               FL_Coord     y,
-               FL_Coord     w,
-               FL_Coord     h,
+               FL_COORD     x,
+               FL_COORD     y,
+               FL_COORD     w,
+               FL_COORD     h,
                const char * label )
 {
     FL_OBJECT *obj;
@@ -101,10 +101,10 @@ fl_create_box( int          type,
 
 FL_OBJECT *
 fl_add_box( int          type,
-            FL_Coord     x,
-            FL_Coord     y,
-            FL_Coord     w,
-            FL_Coord     h,
+            FL_COORD     x,
+            FL_COORD     y,
+            FL_COORD     w,
+            FL_COORD     h,
             const char * label)
 {
     FL_OBJECT *obj = fl_create_box( type, x, y, w, h, label );
