@@ -620,26 +620,39 @@ typedef enum {
     FL_BOLD_STYLE,
     FL_ITALIC_STYLE,
     FL_BOLDITALIC_STYLE,
+	FL_BOLD_ITALIC_STYLE = FL_BOLDITALIC_STYLE,
 
     FL_FIXED_STYLE,
     FL_FIXEDBOLD_STYLE,
+    FL_FIXED_BOLD_STYLE =FL_FIXEDBOLD_STYLE,
     FL_FIXEDITALIC_STYLE,
+    FL_FIXED_ITALIC_STYLE = FL_FIXEDITALIC_STYLE,
     FL_FIXEDBOLDITALIC_STYLE,
+    FL_FIXED_BOLD_ITALIC_STYLE = FL_FIXEDBOLDITALIC_STYLE,
 
     FL_TIMES_STYLE,
 	FL_SERIF_STYLE = FL_TIMES_STYLE,
     FL_TIMESBOLD_STYLE,
+    FL_TIMES_BOLD_STYLE = FL_TIMESBOLD_STYLE,
 	FL_SERIFBOLD_STYLE = FL_TIMESBOLD_STYLE,
+	FL_SERIF_BOLD_STYLE = FL_TIMESBOLD_STYLE,
     FL_TIMESITALIC_STYLE,
+    FL_TIMES_ITALIC_STYLE = FL_TIMESITALIC_STYLE,
 	FL_SERIFITALIC_STYLE = FL_TIMESITALIC_STYLE,
+	FL_SERIF_ITALIC_STYLE = FL_TIMESITALIC_STYLE,
     FL_TIMESBOLDITALIC_STYLE,
+    FL_TIMES_BOLD_ITALIC_STYLE = FL_TIMESBOLDITALIC_STYLE,
 	FL_SERIFBOLDITALIC_STYLE = FL_TIMESBOLDITALIC_STYLE,
+	FL_SERIF_BOLD_ITALIC_STYLE = FL_TIMESBOLDITALIC_STYLE,
 
     FL_MISC_STYLE,
     FL_MISCBOLD_STYLE,
+    FL_MISC_BOLD_STYLE = FL_MISCBOLD_STYLE,
     FL_MISCITALIC_STYLE,
+    FL_MISC_ITALIC_STYLE = FL_MISCITALIC_STYLE,
     FL_SYMBOL_STYLE,
     FL_MISCBOLDITALIC_STYLE = FL_SYMBOL_STYLE,
+    FL_MISC_BOLD_ITALIC_STYLE = FL_SYMBOL_STYLE,
 
     /* Modfier masks, need to fit a (signed) int */
 
