@@ -437,6 +437,10 @@ FL_EXPORT int fl_set_xft_font_name( int              index,
 									FL_FONT_SLANT    slant,
 									FL_FONT_WEIGHT   weight );
 
+FL_EXPORT int fl_set_xft_font_name_f( int          index,
+									  const char * fmt,
+									  ... );
+
 FL_EXPORT void fl_set_default_font_type( FL_FONT_TYPE type );
 
 FL_EXPORT int fl_unload_font( int index );
