@@ -69,3 +69,7 @@ FL_EXPORT int fl_set_dirlist_sort( int method );
 FL_EXPORT int fl_set_dirlist_filterdir( int yes );
 
 FL_EXPORT void fl_free_dirlist( FL_Dirlist * dl );
+
+FL_EXPORT int fl_is_valid_dir(const char * name );
+
+FL_EXPORT char * fl_fix_dirname( char * dir );
