@@ -2129,7 +2129,8 @@ fli_find_last( FL_FORM * form,
 
 
 /***************************************
- * Returns if an object only parially or not at all visible due to clipping
+ * Returns if an object is outside the currently set (global) clipping
+ * region - objects for which 1 is returned don't need redrawing
  ***************************************/
 
 static int
@@ -2140,8 +2141,6 @@ is_object_clipped( FL_OBJECT * obj )
     if ( ! fl_is_global_clipped( ) )
         return 0;
 
-    fli_calc_object_bbox( obj );
-
     xc = fli_intersect_rects( &obj->bbox, fli_get_global_clip_rect( ) );
 
     if ( ! xc )
@@ -2912,10 +2911,10 @@ fli_intersect_rects( const FL_RECT * r1,
 
     p->x      = FL_max( r1->x, r2->x );
     p->y      = FL_max( r1->y, r2->y );
-    p->width  = x - p->x;
-    p->height = y - p->y;
+    p->width  = x - p->x > 0 ? x - p->x : 0;
+    p->height = y - p->y > 0 ? y - p->y : 0;
 
-    if ( p->width <= 0 || p->height <= 0 )
+    if ( p->width == 0 || p->height == 0 )
         fli_safe_free( p );
 
     return p;
@@ -2931,14 +2930,14 @@ static void
 fli_combine_rectangles( FL_RECT       * r1,
                         const FL_RECT * r2 )
 {
-    int xf = FL_max( r1->x + r1->width,  r2->x + r2->width  ),
-        yf = FL_max( r1->y + r1->height, r2->y + r2->height );
+    int x = FL_max( r1->x + r1->width,  r2->x + r2->width  ),
+        y = FL_max( r1->y + r1->height, r2->y + r2->height );
 
     r1->x = FL_min( r1->x, r2->x );
     r1->y = FL_min( r1->y, r2->y );
 
-    r1->width  = xf - r1->x;
-    r1->height = yf - r1->y;
+    r1->width  = x - r1->x;
+    r1->height = y - r1->y;
 }
 
 
@@ -2986,8 +2985,8 @@ fli_scale_object( FL_OBJECT * obj,
         obj->w    = FL_crnd( new_w );
         obj->h    = FL_crnd( new_h );
 
-        fli_calc_object_bbox( obj );
         fli_handle_object( obj, FL_RESIZED, 0, 0, 0, NULL, 0 );
+        fli_calc_object_bbox( obj );
 
         /* If there are child objects also inform them about the size change */
 
