@@ -1647,10 +1647,13 @@ draw_tbox( FL_OBJECT * obj )
 
         if ( tl->selected )
         {
+            fl_set_gc_clipping( sp->selectGC, obj->x + sp->x, obj->y + sp->y,
+                                sp->w + ( LEFT_MARGIN > 0 ), sp->h );
             XFillRectangle( flx->display, FL_ObjWin( obj ), sp->selectGC,
                             obj->x + sp->x,
                             obj->y + sp->y + tl->y - sp->yoffset,
                             obj->w, tl->h );
+            fl_unset_gc_clipping( sp->selectGC );
         }
 
         /* If there's no text or the text isn't visible within the textbox
