@@ -76,9 +76,7 @@ draw( FL_OBJECT * ob )
     FL_COLOR c1,
              c2;
 
-    if ( sp->draw_type == COMPLETE_DRAW )
-        fl_draw_box( ob->boxtype, ob->x, ob->y, ob->w, ob->h, ob->col1,
-                     ob->bw );
+    fl_draw_box( ob->boxtype, ob->x, ob->y, ob->w, ob->h, ob->col1, ob->bw );
 
     x = ob->x + absbw;
     y = ob->y + absbw;
@@ -214,9 +212,6 @@ draw( FL_OBJECT * ob )
             fl_line( x0 - w2 + 11, y + 1, x0 + w2 - 11, y + 1, FL_TOP_BCOL );
         }
     }
-
-    if ( sp->draw_type == COMPLETE_DRAW )
-        fl_draw_object_label_outside( ob );
 }
 
 
@@ -226,9 +221,9 @@ draw( FL_OBJECT * ob )
 static int
 handle_thumbwheel( FL_OBJECT * ob,
                    int         ev,
-                   FL_Coord    mx,
-                   FL_Coord    my,
-                   FL_Char     key,
+                   FL_COORD    mx,
+                   FL_COORD    my,
+                   FL_VAL      key,
                    void      * xev  FL_UNUSED_ARG )
 {
     FLI_THUMBWHEEL_SPEC *sp = ob->spec;
@@ -246,12 +241,10 @@ handle_thumbwheel( FL_OBJECT * ob,
 
         case FL_DRAW:
             draw( ob );
-            sp->draw_type = COMPLETE_DRAW;
             break;
 
         case FL_DRAWLABEL:
-            if ( sp->draw_type == COMPLETE_DRAW )
-                fl_draw_object_label_outside( ob );
+            fl_draw_object_label_outside( ob );
             break;
 
         case FL_PUSH:
@@ -475,10 +468,10 @@ fl_set_thumbwheel_return( FL_OBJECT    * obj,
 
 FL_OBJECT *
 fl_create_thumbwheel( int          type,
-                      FL_Coord     x,
-                      FL_Coord     y,
-                      FL_Coord     w,
-                      FL_Coord     h,
+                      FL_COORD     x,
+                      FL_COORD     y,
+                      FL_COORD     w,
+                      FL_COORD     h,
                       const char * label )
 {
     FL_OBJECT *obj;
@@ -509,10 +502,10 @@ fl_create_thumbwheel( int          type,
 
 FL_OBJECT *
 fl_add_thumbwheel( int          type,
-                   FL_Coord     x,
-                   FL_Coord     y,
-                   FL_Coord     w,
-                   FL_Coord     h,
+                   FL_COORD     x,
+                   FL_COORD     y,
+                   FL_COORD     w,
+                   FL_COORD     h,
                    const char * label )
 {
     FL_OBJECT *obj = fl_create_thumbwheel( type, x, y, w, h, label );
